SWFObject
=========

sources: http://code.google.com/p/swfobject/wiki/documentation

What is SWFObject?
------------------

Offers two optimized Flash Player embed methods:

* a markup based approach
* a method that relies on JavaScript

It offers a JavaScript API that aims to provide a complete tool set for
embedding SWF files and retrieving Flash Player related information
Utilizes only one small JavaScript file (10Kb / GZIPed: 3.9Kb)
Is the successor of SWFObject 1.5, UFO and the Adobe Flash Player Detection Kit
Intends to unify all existing Flash Player embed methods and provide a new
standard for embedding Adobe Flash Player content

Why should you use SWFObject?
-----------------------------

* Is more optimized and flexible than any other Flash Player embed method around
* Offers one solution for everybody: It shouldn't matter if you are an HTML,
Flash, or JavaScript developer, there should be something in it for everyone
* Breaks the cycle of being locked into vendor specific markup and promotes
the use of web standards and alternative content
* Uses unobtrusive JavaScript and JavaScript best practices
* Is easy to use

Why should I use this add-on
===========================

I guess if you read this it is because you already want to use swfobject.

Because this add-on will keep the javascript swfobject up to date for you.

Because you don't want three versions of swfobject into the same site.

List of add-ons using swfobject
===============================

* collective.flowplayer
* collective.cu3er
* quintagroup.portlet.cumulus
* collective.dewplayer

